@@ -22,11 +22,11 @@ class _TestDatabase(object):
 
     def test_stored_prefixes(self):
         t = tempfile.mkdtemp()
-        x = xapian.WritableDatabase(t, xapian.DB_CREATE_OR_OVERWRITE)
-        x.set_metadata("_XODB_RP_Foo", "bar")
-        x.set_metadata("_XODB_BP_Ding", "dong")
-        x.flush()
-        xdb = xodb.Database(x)
+        xdb = xodb.Database(t)
+        xdb.backend.set_metadata("_XODB_RP_Foo", "bar")
+        xdb.backend.set_metadata("_XODB_BP_Ding", "dong")
+        xdb.reopen()
+
         assert xdb.relevance_prefixes['Foo'] == 'bar'
         assert xdb.boolean_prefixes['Ding'] == 'dong'
 
@@ -45,10 +45,6 @@ class TestXapianFile(_TestDatabase):
     db_factory = staticmethod(xodb.temp)
 
 
-class TestXapianInMem(_TestDatabase):
-    db_factory = staticmethod(xodb.inmemory)
-
-
 def test_value_range_processor():
     vp = MultipleValueRangeProcessor(dict(foo=1, bar=2), str.upper)
     assert vp('foo:abc', 'def') == (1, 'ABC', 'DEF')
