@@ -156,27 +156,24 @@ class Database(object):
     value_prefix = "_XODB_VALUE_"
     value_sort_prefix = "_XODB_VALUESORT_"
     value_count_name = "_XODB_COUNT_"
-    db_path = None
+    backend = None
 
-    def __init__(self, db_or_path,
-                 writable=True, overwrite=False, spelling=True):
+    def __init__(self, path, writable=True, overwrite=False, spelling=True):
+        self.db_path = path
         self._writable = writable
-        self.backend = db_or_path
+        self._overwrite = overwrite
         self.spelling = spelling
+        self.open()
 
-        if isinstance(db_or_path, basestring):
-            if writable:
-                if overwrite:
-                    flags = xapian.DB_CREATE_OR_OVERWRITE
-                else:
-                    flags = xapian.DB_CREATE_OR_OPEN
-                self.backend = xapian.WritableDatabase(db_or_path, flags)
+    def open(self):
+        if self._writable:
+            if self._overwrite:
+                flags = xapian.DB_CREATE_OR_OVERWRITE
             else:
-                self.backend = xapian.Database(db_or_path)
-            self.db_path = db_or_path
-        elif not isinstance(db_or_path, xapian.Database):
-            raise TypeError(
-                'First argument must be path or xapian.[Writable]Database')
+                flags = xapian.DB_CREATE_OR_OPEN
+            self.backend = xapian.WritableDatabase(self.db_path, flags)
+        else:
+            self.backend = xapian.Database(self.db_path)
 
         self.relevance_prefixes = {}
         self.boolean_prefixes = {}
@@ -185,6 +182,9 @@ class Database(object):
         self.type_map = {}
         self.reopen()
 
+    def close(self):
+        self.backend.close()
+
     def map(self, otype, schema):
         """Map a type to a schema."""
         self.type_map[otype] = schema
