@@ -95,32 +95,35 @@ class Schema(schema.Form):
         for el in parent.all_children:
             if el.index:
                 if isinstance(el, String):
-                    h = self._handle_string
+                    handler = self._handle_string
                 elif isinstance(el, Integer):
-                    h = self._handle_integer
+                    handler = self._handle_integer
                 elif isinstance(el, Float):
-                    h = self._handle_float
+                    handler = self._handle_float
                 elif isinstance(el, Boolean):
-                    h = self._handle_boolean
+                    handler = self._handle_boolean
                 elif isinstance(el, Date):
-                    h = self._handle_date
+                    handler = self._handle_date
                 elif isinstance(el, DateTime):
-                    h = self._handle_date
+                    handler = self._handle_date
                 elif isinstance(el, Text):
-                    h = self._handle_text
+                    handler = self._handle_text
                 elif isinstance(el, NumericRange):
-                    h = self._handle_numericrange
+                    handler = self._handle_numericrange
                 elif isinstance(el, Location):
-                    h = self._handle_location
+                    handler = self._handle_location
                 elif isinstance(el, List):
-                    h = self._handle_children
+                    handler = self._handle_children
                 elif isinstance(el, Dict):
-                    h = self._handle_children
+                    handler = self._handle_children
                 elif isinstance(el, Array):
-                    h = self._handle_children
+                    handler = self._handle_children
                 else:
                     raise TypeError("Unknown element %s" % el)
-                h(el)
+
+                if el.facet:
+                    self._add_term(el.name, self.facet_prefix, True)
+                handler(el)
 
     def _handle_scalar(self, term, value, element,
                        type=None, serialize=False):
@@ -129,8 +132,6 @@ class Schema(schema.Form):
             self._add_term(term, name, element.boolean)
         else:
             self._add_term(term)
-        if element.facet:
-            self._add_term(name, self.facet_prefix, True)
         if element.sortable:
             if serialize:
                 self._add_value(
@@ -200,9 +201,6 @@ class Schema(schema.Form):
         else:
             index_text(value)
 
-        if element.facet:
-            self._add_term(name, self.facet_prefix, True)
-
     def _handle_numericrange(self, element):
         maxv = element['high'].value or 0
         minv = element['low'].value or 0
@@ -222,14 +220,9 @@ class Schema(schema.Form):
             val = "%s_%s" % (i, i + step)
             self._add_term(val, element.name, True)
 
-        if element.facet:
-            self._add_term(element.name, self.facet_prefix, True)
-
     def _handle_location(self, element):
         h = 'loc_' + element.hash(element.radians)
         self._add_term(h, boolean=True)
-        if element.facet:
-            self._add_term(element.name, self.facet_prefix, True)
 
     def _check_prefix(self, name, boolean=False):
         database = self.database
